@@ -112,16 +112,18 @@ def persist_messages(collection: StandardCollection, messages: io.TextIOWrapper,
             try:
                 rec = o['record']
                 try:
-                    kps = key_properties[stream]
-                    if len(kps) > 1:
-                        logger.warn(f'Multiple key_properties found ({",".join(kps)}).'
-                                    f' Only `{kps[0]}` will be considered.')
-                    _key = str(rec[kps[0]]).strip()
-
+                    kps = key_properties.get('stream')
+                    _key = None
                     # Appending _ to keys inorder for preserving values of reserved keys in source data
                     reserved_keys = ['_key', '_id', '_rev']
-                    if kps[0] == '_key':
-                        reserved_keys.remove('_key')
+
+                    if kps:
+                        if len(kps) > 1:
+                            logger.warn(f'Multiple key_properties found ({",".join(kps)}).'
+                                        f' Only `{kps[0]}` will be considered.')
+                        _key = str(rec[kps[0]]).strip()
+                        if kps[0] == '_key':
+                            reserved_keys.remove('_key')
 
                     for reserved_key in reserved_keys:
                         if rec.get(reserved_key):
@@ -132,14 +134,13 @@ def persist_messages(collection: StandardCollection, messages: io.TextIOWrapper,
                                 else:
                                     break
                             rec[new_key] = rec.pop(reserved_key)
-                            logger.info(f"Reserved key: {reserved_key} exists in source data changing key to: {new_key}")
 
-                    if not (1 <= len(_key) <= 254 and bool(re.match("^[-_!\$%'\(\)\*\+,\.:;=@a-zA-Z0-9]+$", _key))):
+                    if _key and not (1 <= len(_key) <= 254 and bool(re.match("^[-_!\$%'\(\)\*\+,\.:;=@a-zA-Z0-9]+$", _key))):
                         hashed_key = hashlib.sha256(_key.encode('utf-8'))
                         _key = hashed_key.hexdigest()
                         logger.info(f"Primary key of the source doesn't satisfy the constraints of macrometa "
                                     f"document key, Hashing the key and using it in hex form to make it compliant.")
-                    rec['_key'] = _key
+                        rec['_key'] = _key
                 except:
                     _key = None
                 if '_sdc_deleted_at' in rec:
